@@ -25,6 +25,7 @@ import codecs
 import io
 import six
 
+
 class Fail(BaseException):
     """
     Exception raised when a validation or lookup fails
@@ -33,6 +34,7 @@ class Fail(BaseException):
         self.code = code
         self.msg = msg
 
+
 class ClusterFail(Fail):
     """
     Exception raised to report a number of errors of the same kind
@@ -41,6 +43,7 @@ class ClusterFail(Fail):
         super(ClusterFail, self).__init__(code, msg)
         self.errors = errors
 
+
 def get_key(d, key):
     "Get a key from a dict"
     try:
@@ -48,6 +51,7 @@ def get_key(d, key):
     except KeyError:
         raise Fail(400, "Key '{}' not found".format(key))
 
+
 def get_key_int(d, key):
     "Get a key from a dict, as an int"
     try:
@@ -55,11 +59,13 @@ def get_key_int(d, key):
     except ValueError:
         raise Fail(400, "Key '{}' does not contain an integer value".format(key))
 
+
 def get_key_string(d, key, empty=False):
     "Get a key from a dict, as a string"
     if empty:
         res = d.get(key, "")
-        if not res: return ""
+        if not res:
+            return ""
     else:
         res = get_key(d, key)
 
@@ -73,11 +79,13 @@ def get_key_string(d, key, empty=False):
 
     return res
 
+
 def get_key_unicode(d, key, empty=False):
     "Get a key from a dict, as a unicode, decoded from utf8 if necessary"
     if empty:
         res = d.get(key, "")
-        if not res: return ""
+        if not res:
+            return ""
     else:
         res = get_key(d, key)
         if not res:
@@ -94,6 +102,7 @@ def get_key_unicode(d, key, empty=False):
         escaped = res.decode(encoding="utf8", errors="replace")
         raise Fail(400, "Key '{}' contain {} which is not a valid UTF8 string".format(key, escaped))
 
+
 def get_key_sequence(d, key):
     "Get a key from a dict, ensuring it is a list or tuple"
     res = get_key(d, key)
@@ -101,6 +110,7 @@ def get_key_sequence(d, key):
         raise Fail(400, "Key '{}' does not contain an array".format(key))
     return res
 
+
 def get_key_sequence_or_object(d, key):
     """
     Get a key from a dict, ensuring it is a list or tuple, allowing singleton
@@ -114,16 +124,19 @@ def get_key_sequence_or_object(d, key):
     else:
         raise Fail(400, "Key '{}' does not contain an array or object".format(key))
 
+
 def get_key_date_or_none(d, key):
     "Get a key from a dict, as a date, allowing None"
     res = get_key_string(d, key, empty=True)
-    if not res: return None
+    if not res:
+        return None
 
     try:
         return datetime.datetime.strptime(res, "%Y-%m-%d").date()
     except ValueError:
         raise Fail(400, "Key '{}' does not contain a YYYY-MM-DD date".format(key))
 
+
 def get_json(f, compression=None):
     """
     Parse JSON from data from a file-like object, with optional decompression
@@ -222,11 +235,11 @@ class Parser(object):
                 s_contribs = [self.parse_contribution(d)
                               for d in get_key_sequence_or_object(rec, "contributions")]
             except Fail as f:
-                errors.append("#{} for {}: cannot parse contribution(s): {}".format(idx, s_id[0].id, f.msg))
+                errors.append("#{} for {}: cannot parse contribution(s): {}".format(idx, s_ids[0].id, f.msg))
                 continue
 
             if not s_contribs:
-                errors.append("#{} for {}: contribution list is empty".format(idx, s_id[0].id))
+                errors.append("#{} for {}: contribution list is empty".format(idx, s_ids[0].id))
                 continue
 
             yield s_ids, s_contribs
