@@ -121,7 +121,7 @@ class Postgres(scanner.Scanner):
 
             contribs.add(id, date)
 
-        for id, (begin, end) in contribs.iteritems():
+        for id, (begin, end) in contribs.items():
             if self.identifier == "auto":
                 try:
                     ident = Identifier.create_auto(id, default_desc=desc_by_id.get(id, None))
